==> haskell-data-default-instances-dlist-0.0.1.2-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-dlist
version:              0.0.1.2
visibility:           public
id:                   data-default-instances-dlist-0.0.1.2-7erc9w3oDsE8NbDcWhJwpp
key:                  data-default-instances-dlist-0.0.1.2-7erc9w3oDsE8NbDcWhJwpp
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in dlist
description:
    This module defines a '\''Default'\'' instance for the type '\''DList'\''.

category:             Data
abi:                  e67b00f0bef419c6ddb16d6a99d0c402
exposed:              True
exposed-modules:      Data.Default.Instances.DList
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-dlist
hs-libraries:
    HSdata-default-instances-dlist-0.0.1.2-7erc9w3oDsE8NbDcWhJwpp

depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    dlist-1.0-EiF8i83CnLm6sCDQL6jgx6

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-dlist-0.0.1.2-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-dlist
version:              0.0.1.2
visibility:           public
id:                   data-default-instances-dlist-0.0.1.2-LaUtX5PuvLb8xRU8p8er8J
key:                  data-default-instances-dlist-0.0.1.2-LaUtX5PuvLb8xRU8p8er8J
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in dlist
description:
    This module defines a '\''Default'\'' instance for the type '\''DList'\''.

category:             Data
abi:                  a0ac4b6895999624c182ddb25cd2c4fb
exposed:              True
exposed-modules:      Data.Default.Instances.DList
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-dlist
hs-libraries:
    HSdata-default-instances-dlist-0.0.1.2-LaUtX5PuvLb8xRU8p8er8J

depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    dlist-1.0-Aes7b3zqgHz83Qc440Ai0X

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
